=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2005-07-29 17:19:16 +0000
+++ bzrlib/commands.py	2005-07-23 14:06:37 +0000
@@ -122,20 +122,6 @@
     return revs
 
 
-def get_merge_type(typestring):
-    """Attempt to find the merge class/factory associated with a string."""
-    from merge import merge_types
-    try:
-        return merge_types[typestring][0]
-    except KeyError:
-        templ = '%s%%7s: %%s' % (' '*12)
-        lines = [templ % (f[0], f[1][1]) for f in merge_types.iteritems()]
-        type_list = '\n'.join(lines)
-        msg = "No known merge type %s. Supported types are:\n%s" %\
-            (typestring, type_list)
-        raise BzrCommandError(msg)
-    
-
 
 def _get_cmd_dict(plugins_override=True):
     d = {}
@@ -1407,15 +1393,12 @@
     --force is given.
     """
     takes_args = ['other_spec', 'base_spec?']
-    takes_options = ['force', 'merge-type']
+    takes_options = ['force']
 
-    def run(self, other_spec, base_spec=None, force=False, merge_type=None):
+    def run(self, other_spec, base_spec=None, force=False):
         from bzrlib.merge import merge
-        from bzrlib.merge_core import ApplyMerge3
-        if merge_type is None:
-            merge_type = ApplyMerge3
         merge(parse_spec(other_spec), parse_spec(base_spec),
-              check_clean=(not force), merge_type=merge_type)
+              check_clean=(not force))
 
 
 
@@ -1437,12 +1420,14 @@
 class cmd_merge_revert(Command):
     """Reverse all changes since the last commit.
 
-    Only versioned files are affected.  By default, any files that are changed
-    will be backed up first.  Backup files have a '~' appended to their name.
+    Only versioned files are affected.
+
+    TODO: Store backups of any files that will be reverted, so
+          that the revert can be undone.          
     """
-    takes_options = ['revision', 'no-backup']
+    takes_options = ['revision']
 
-    def run(self, revision=None, no_backup=False):
+    def run(self, revision=None):
         from bzrlib.merge import merge
         if revision is None:
             revision = [-1]
@@ -1450,8 +1435,7 @@
             raise BzrCommandError('bzr merge-revert --revision takes exactly 1 argument')
         merge(('.', revision[0]), parse_spec('.'),
               check_clean=False,
-              ignore_zero=True,
-              backup_files=not no_backup)
+              ignore_zero=True)
 
 
 class cmd_assert_fail(Command):
@@ -1516,8 +1500,6 @@
     'update':                 None,
     'long':                   None,
     'root':                   str,
-    'no-backup':              None,
-    'merge-type':             get_merge_type,
     }
 
 SHORT_OPTIONS = {

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2005-07-29 17:19:16 +0000
+++ bzrlib/merge.py	2005-07-26 17:44:20 +0000
@@ -1,6 +1,7 @@
-from merge_core import merge_flex, ApplyMerge3, BackupBeforeChange
+from merge_core import merge_flex
 from changeset import generate_changeset, ExceptionConflictHandler
 from changeset import Inventory, Diff3Merge
+from merge_core import ApplyMerge3
 from bzrlib import find_branch
 import bzrlib.osutils
 from bzrlib.errors import BzrCommandError
@@ -165,7 +166,7 @@
 
 def merge(other_revision, base_revision,
           check_clean=True, ignore_zero=False,
-          this_dir=None, backup_files=False, merge_type=ApplyMerge3):
+          this_dir=None):
     """Merge changes into a tree.
 
     base_revision
@@ -201,8 +202,7 @@
             base_revision = ['.', base_revno]
         base_branch, base_tree = get_tree(base_revision, tempdir, "base")
         merge_inner(this_branch, other_tree, base_tree, tempdir, 
-                    ignore_zero=ignore_zero, backup_files=backup_files, 
-                    merge_type=merge_type)
+                    ignore_zero=ignore_zero)
     finally:
         shutil.rmtree(tempdir)
 
@@ -232,13 +232,12 @@
 
 
 def merge_inner(this_branch, other_tree, base_tree, tempdir, 
-                ignore_zero=False, merge_type=ApplyMerge3, backup_files=False):
+                ignore_zero=False, merge_type="diff3"):
+    merge_types = {"merge3": ApplyMerge3, 
+                   "diff3": Diff3Merge}
 
     def merge_factory(base_file, other_file):
-        contents_change = merge_type(base_file, other_file)
-        if backup_files:
-            contents_change = BackupBeforeChange(contents_change)
-        return contents_change
+        return merge_types[merge_type](base_file, other_file)
 
     this_tree = get_tree((this_branch.base, None), tempdir, "this")[1]
 
@@ -303,8 +302,3 @@
     assert len(new_inventory_list) == len(old_entries) + insertions - deletions
     new_inventory_list.sort()
     return new_inventory_list
-
-merge_types = {     "merge3": (ApplyMerge3, "Native diff3-style merge"), 
-                     "diff3": (Diff3Merge,  "Merge using external diff3")
-              }
-

=== modified file 'bzrlib/merge_core.py'
--- bzrlib/merge_core.py	2005-07-28 18:46:35 +0000
+++ bzrlib/merge_core.py	2005-07-28 13:37:16 +0000
@@ -1,7 +1,6 @@
 import changeset
 from changeset import Inventory, apply_changeset, invert_dict
 import os.path
-from osutils import backup_file
 from merge3 import Merge3
 
 class ApplyMerge3:
@@ -50,25 +49,6 @@
         else:
             conflict_handler.merge_conflict(new_file, filename, base, other)
 
-
-class BackupBeforeChange:
-    """Contents-change wrapper to back up file first"""
-    def __init__(self, contents_change):
-        self.contents_change = contents_change
- 
-    def __eq__(self, other):
-        if not isinstance(other, BackupBeforeChange):
-            return False
-        return (self.contents_change == other.contents_change)
-
-    def __ne__(self, other):
-        return not (self == other)
-
-    def apply(self, filename, conflict_handler, reverse=False):
-        backup_file(filename)
-        self.contents_change.apply(filename, conflict_handler, reverse)
-
-
 class ThreewayInventory(object):
     def __init__(self, this_inventory, base_inventory, other_inventory):
         self.this = this_inventory
@@ -568,25 +548,8 @@
         """Test diff3 merging"""
         self.do_contents_test(changeset.Diff3Merge)
 
-    def test_contents_merge3(self):
-        """Test diff3 merging"""
-        def backup_merge(base_file, other_file):
-            return BackupBeforeChange(ApplyMerge3(base_file, other_file))
-        builder = self.contents_test_success(backup_merge)
-        def backup_exists(file_id):
-            return os.path.exists(builder.this.full_path(file_id)+"~")
-        assert backup_exists("1")
-        assert backup_exists("2")
-        assert not backup_exists("3")
-        builder.cleanup()
-
     def do_contents_test(self, merge_factory):
         """Test merging with specified ContentsChange factory"""
-        builder = self.contents_test_success(merge_factory)
-        builder.cleanup()
-        self.contents_test_conflicts(merge_factory)
-
-    def contents_test_success(self, merge_factory):
         from inspect import isclass
         builder = MergeBuilder()
         builder.add_file("1", "0", "name1", "text1", 0755)
@@ -609,9 +572,8 @@
         assert(os.stat(builder.this.full_path("1")).st_mode &0777 == 0755)
         assert(os.stat(builder.this.full_path("2")).st_mode &0777 == 0655)
         assert(os.stat(builder.this.full_path("3")).st_mode &0777 == 0744)
-        return builder
+        builder.cleanup()
 
-    def contents_test_conflicts(self, merge_factory):
         builder = MergeBuilder()
         builder.add_file("1", "0", "name1", "text1", 0755)
         builder.change_contents("1", other="text4", this="text3")

